package Locale::CLDR::Locales::Chr::Any;

# This file auto generated
#	on Mon 11 Apr  5:25:41 pm GMT

use version;

our $VERSION = version->declare('v0.34.1');

use v5.10.1;
use mro 'c3';
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Chr');

no Moo;

1;
